@@ -1,7 +1,7 @@
+package Geo::Address::Formatter;
+$Geo::Address::Formatter::VERSION = '1.98';
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
-package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.97';
 use strict;
 use warnings;
 use feature qw(say);
@@ -80,14 +80,14 @@ sub _read_configuration {
             }
         }
         foreach my $rh_c (@c) {
-            $self->{all_components}{$rh_c->{name}} = 1;
+            push(@{$self->{ordered_components}}, $rh_c->{name});
             if (defined($rh_c->{aliases})) {
                 foreach my $alias (@{$rh_c->{aliases}}) {
-                    $self->{all_components}{$alias} = 1;;
+                    push(@{$self->{ordered_components}}, $alias);
                 }
             }
         }
-        # say Dumper $self->{all_components};
+        #say Dumper $self->{ordered_components};            
     } catch {
         warn "error parsing component configuration: $_";
     };
@@ -795,8 +795,10 @@ sub _find_unknown_components {
     my $self       = shift;
     my $rh_components = shift;
 
-    my @a_unknown = grep { !exists($self->{all_components}{$_}) } 
-                    sort keys %$rh_components;
+    my %h_known   = map  { $_ => 1 } @{$self->{ordered_components}};
+    my @a_unknown = grep { !exists($h_known{$_}) } sort keys %$rh_components;
+#    my @a_unknown = grep { !exists($self->{all_components}{$_}) } 
+#                    sort keys %$rh_components;
 
     return \@a_unknown;
 }
@@ -815,7 +817,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.97
+version 1.98
 
 =head1 SYNOPSIS
 
